WindowManager_WindowProperties

Struct WindowManager_WindowProperties 

#[repr(C)]
pub struct WindowManager_WindowProperties {
Show 13 fields pub windowRect: WindowManager_Rect, pub drawableRect: WindowManager_Rect, pub type_: WindowManager_WindowType, pub isFullScreen: bool, pub isLayoutFullScreen: bool, pub focusable: bool, pub touchable: bool, pub brightness: f32, pub isKeepScreenOn: bool, pub isPrivacyMode: bool, pub isTransparent: bool, pub id: u32, pub displayId: u32,
}
Available on crate feature api-15 only.
Properties of window

Available since API-level: 15

Fields

windowRect: WindowManager_Rect

The position and size of the window.

drawableRect: WindowManager_Rect

The position relative to the window and size of drawable area.

type_: WindowManager_WindowType

Window type.

isFullScreen: bool

Whether the window is displayed in full screen mode. The default value is false.

isLayoutFullScreen: bool

Whether the window layout is full screen mode. The default value is false.

focusable: bool

Whether the window can gain focus. The default value is true.

touchable: bool

Whether the window is touchable. The default value is false.

brightness: f32

Brightness value of window.

isKeepScreenOn: bool

Whether keep screen on.

isPrivacyMode: bool

Whether make window in privacy mode or not.

isTransparent: bool

Whether is transparent or not.

id: u32

Window id.

displayId: u32

Display id.