pub unsafe extern "C" fn OH_WindowManager_SetWindowNavigationBarEnabled(
windowId: i32,
enabled: bool,
enableAnimation: bool,
) -> i32Available on crate feature
api-15 only.Expand description
Set whether to show navigation bar.
Arguments
-
windowId- WindowId when window is created. -
enabled- If true, the navigation bar is displayed. If false, the navigation bar is hidden. -
enableAnimation- If true, the navigation bar is displayed and hidden with animation. If false, the navigation bar is displayed and hidden with no animation.
Returns
- Returns the result code.
[
OK] the function call is successful. [WINDOW_MANAGER_ERRORCODE_DEVICE_NOT_SUPPORTED] capability not supported. [WINDOW_MANAGER_ERRORCODE_STATE_ABNORMAL] this window state is abnormal. [WINDOW_MANAGER_ERRORCODE_SYSTEM_ABNORMAL] the window manager service works abnormally.
Available since API-level: 15