#[repr(C)]pub struct WindowManager_WindowProperties {Show 13 fields
pub windowRect: WindowManager_Rect,
pub drawableRect: WindowManager_Rect,
pub type_: WindowManager_WindowType,
pub isFullScreen: bool,
pub isLayoutFullScreen: bool,
pub focusable: bool,
pub touchable: bool,
pub brightness: f32,
pub isKeepScreenOn: bool,
pub isPrivacyMode: bool,
pub isTransparent: bool,
pub id: u32,
pub displayId: u32,
}Available on crate feature
api-15 only.Expand description
Properties of window
Available since API-level: 15
Fields
windowRect: WindowManager_RectThe position and size of the window.
drawableRect: WindowManager_RectThe position relative to the window and size of drawable area.
type_: WindowManager_WindowTypeWindow type.
isFullScreen: boolWhether the window is displayed in full screen mode. The default value is false.
isLayoutFullScreen: boolWhether the window layout is full screen mode. The default value is false.
focusable: boolWhether the window can gain focus. The default value is true.
touchable: boolWhether the window is touchable. The default value is false.
brightness: f32Brightness value of window.
isKeepScreenOn: boolWhether keep screen on.
isPrivacyMode: boolWhether make window in privacy mode or not.
isTransparent: boolWhether is transparent or not.
id: u32Window id.
displayId: u32Display id.